@@ -6,21 +6,17 @@ Kafka::Connection - Object interface to connect to a kafka cluster.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Connection> version 1.02 .
+This documentation refers to C<Kafka::Connection> version 1.03 .
 
 =cut
 
-#-- Pragmas --------------------------------------------------------------------
-
 use 5.010;
 use strict;
 use warnings;
 
-# ENVIRONMENT ------------------------------------------------------------------
-
 our $DEBUG = 0;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 use Exporter qw(
     import
@@ -29,8 +25,6 @@ our @EXPORT = qw(
     %RETRY_ON_ERRORS
 );
 
-#-- load the modules -----------------------------------------------------------
-
 use Data::Validate::Domain qw(
     is_hostname
 );
@@ -141,8 +135,6 @@ use Kafka::Protocol qw(
     encode_api_versions_request
 );
 
-#-- declarations ---------------------------------------------------------------
-
 =head1 SYNOPSIS
 
     use 5.010;
@@ -406,11 +398,8 @@ API endpoints.
 If set to true, the client will always use
 C<$Kafka::Protocol::DEFAULT_APIVERSION> as API version.
 
-=item C<api_versions_refresh_delay_sec =E<gt> $positive_integer>
-
-Optional, default value is 60 (1 minute).
-
-The delay after which the client will refresh the supported API versions.
+WARNING: API versions are supported starting from Kafka 0.10. Set this parameter to true
+if you're connecting to 0.9.
 
 =back
 
@@ -429,7 +418,6 @@ sub new {
         AutoCreateTopicsEnable  => 0,
         MaxLoggedErrors         => 100,
         dont_load_supported_api_versions => 0,
-        api_versions_refresh_delay_sec => 60,
     }, $class;
 
     while ( @args ) {
@@ -547,13 +535,29 @@ sub _get_api_versions {
 
     # call the server and try to get the supported API versions
     my $api_versions = [];
+    my $error;
     try {
         # The ApiVersions API endpoint is only supported on Kafka versions >
         # 0.10.0.0 so this call may fail. We simply ignore this failure and
         # carry on.
-        $api_versions = $self->_get_supported_api_versions($server);
+        $api_versions = $self->_get_supported_api_versions( $server );
+    }
+    catch {
+        $error = $_;
     };
 
+    if( defined $error ) {
+        if ( blessed( $error ) && $error->isa( 'Kafka::Exception' ) ) {
+            if( $error->code == $ERROR_MISMATCH_ARGUMENT ) {
+                # rethrow known fatal errors
+                die $error;
+            }
+            $self->_remember_nonfatal_error( $error->code, $error, $server );
+        } else {
+            die $error;
+        }
+    }
+
     foreach my $element (@$api_versions) {
         # we want to choose which api version to use for each API call. We
         # try to use the max version that the server supports, with
@@ -575,7 +579,6 @@ sub _get_api_versions {
     return $server_api_versions;
 }
 
-
 # Returns the list of supported API versions. This is not really. *Warning*,
 # this call works only against Kafka 1.10.0.0
 
@@ -832,14 +835,22 @@ sub receive_response_to_request {
 
         # Send a request to the leader
         if ( $self->_connectIO( $server ) ) {
-
             # we can connect to this leader, so let's detect the api versions
             # it and use whatever it supports, except if the request forces us
             # to use an api version. Warning, the version might end up being
             # undef if detection against the Kafka server failed, or if
             # dont_load_supported_api_versions is true. However the Encoder
             # code knows how to handle it.
-            $request->{ApiVersion} = $original_request_api_version // $self->_get_api_versions($server)->{$api_key};
+            $request->{ApiVersion} = $original_request_api_version;
+            unless( defined $request->{ApiVersion} ) {
+                $request->{ApiVersion} = $self->_get_api_versions( $server )->{ $api_key };
+                # API versions request may fail and the server may be disconnected
+                unless( $self->_is_IO_connected( $server ) ) {
+                    # this attempt does not count, assuming that _get_api_versions will not try to get them from failing broker again
+                    redo ATTEMPT;
+                }
+            }
+
             my $encoded_request = $protocol{ $api_key }->{encode}->( $request, $compression_codec );
 
             unless ( $self->_sendIO( $server, $encoded_request ) ) {
@@ -1225,9 +1236,8 @@ sub _update_metadata {
     $IO_cache->{ $_ }->{NodeId} = undef for @brokers;
 
     #  In the IO cache update/add obtained server information
-    my $server;
     foreach my $received_broker ( @{ $decoded_response->{Broker} } ) {
-        $server = $self->_build_server_name( @{ $received_broker }{ 'Host', 'Port' } );
+        my $server = $self->_build_server_name( @{ $received_broker }{ 'Host', 'Port' } );
         $IO_cache->{ $server } = {                      # can add new servers
             IO      => $IO_cache->{ $server }->{IO},    # IO or undef
             NodeId  => $received_broker->{NodeId},
@@ -1242,13 +1252,12 @@ sub _update_metadata {
     my $received_metadata   = {};
     my $leaders             = {};
 
-    my ( $TopicName, $partition );
     my $ErrorCode = $ERROR_NO_ERROR;
+    my( $TopicName, $partition );
     METADATA_CREATION:
     foreach my $topic_metadata ( @{ $decoded_response->{TopicMetadata} } ) {
-        $partition = undef;
-
         $TopicName = $topic_metadata->{TopicName};
+        undef $partition;
         last METADATA_CREATION
             if ( $ErrorCode = $topic_metadata->{ErrorCode} ) != $ERROR_NO_ERROR;
 
@@ -1276,10 +1285,6 @@ sub _update_metadata {
         }
     }
 
-    %$received_metadata
-        # FATAL error
-        or $self->_error( $ERROR_CANNOT_GET_METADATA, format_message( "topic='%s'", $topic ) );
-
     # Update metadata for received topics
     $self->{_metadata}->{ $_ }  = $received_metadata->{ $_ } foreach keys %{ $received_metadata };
     $self->{_leaders}->{ $_ }   = $leaders->{ $_ } foreach keys %{ $leaders };
@@ -1351,6 +1356,12 @@ sub _io_error {
     return $error;
 }
 
+sub _is_IO_connected {
+    my ( $self, $server ) = @_;
+    my $server_data = $self->{_IO_cache}->{ $server } or return;
+    return $server_data->{IO};
+}
+
 # connects to a server (host:port or [IPv6_host]:port)
 sub _connectIO {
     my ( $self, $server ) = @_;
@@ -1381,20 +1392,25 @@ sub _connectIO {
     return $server_data->{IO};
 }
 
-# Send encoded request ($encoded_request) to server ($server)
-sub _sendIO {
-    my ( $self, $server, $encoded_request ) = @_;
-
+sub _server_data_IO {
+    my ( $self, $server ) = @_;
     my $server_data = $self->{_IO_cache}->{ $server }
         or $self->_error( $ERROR_MISMATCH_ARGUMENT, format_message( "Unknown server '%s' (is not found in the metadata)", $server ) )
     ;
     $self->_error( $ERROR_MISMATCH_ARGUMENT, format_message( "Server '%s' is not connected", $server ) )
         unless $server_data->{IO}
     ;
+    return ( $server_data, $server_data->{IO} );
+}
+
+# Send encoded request ($encoded_request) to server ($server)
+sub _sendIO {
+    my ( $self, $server, $encoded_request ) = @_;
+    my( $server_data, $io ) = $self->_server_data_IO( $server );
     my $sent;
     my $error;
     try {
-        $sent = $server_data->{IO}->send( $encoded_request );
+        $sent = $io->send( $encoded_request );
     } catch {
         $error = $_;
     };
@@ -1409,13 +1425,7 @@ sub _sendIO {
 # Receive response from a given server
 sub _receiveIO {
     my ( $self, $server, $response_timeout ) = @_;
-
-    my $server_data = $self->{_IO_cache}->{ $server }
-        or $self->_error( $ERROR_MISMATCH_ARGUMENT, format_message( "Unknown server '%s' (is not found in the metadata)", $server ) )
-    ;
-    my $io = $server_data->{IO}
-        or $self->_error( $ERROR_MISMATCH_ARGUMENT, format_message( "Server '%s' is not connected", $server ) )
-    ;
+    my( $server_data, $io ) = $self->_server_data_IO( $server );
     my $response_ref;
     my $error;
     try {
@@ -1477,8 +1487,6 @@ sub _error {
     Kafka::Exception::Connection->throw( throw_args( @_ ) );
 }
 
-#-- Closes and cleans up -------------------------------------------------------
-
 1;
 
 __END__
@@ -1587,7 +1595,7 @@ L<https://github.com/TrackingSoft/Kafka>
 
 =head1 AUTHOR
 
-Sergey Gladkov, E<lt>sgladkov@trackingsoft.comE<gt>
+Sergey Gladkov
 
 Please use GitHub project link above to report problems or contact authors.
 
@@ -1616,3 +1624,4 @@ without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 PARTICULAR PURPOSE.
 
 =cut
+
