@@ -6,21 +6,21 @@ Kafka::Consumer - Perl interface for Kafka consumer client.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Consumer> version 1.02 .
+This documentation refers to C<Kafka::Consumer> version 1.03 .
 
 =cut
 
-#-- Pragmas --------------------------------------------------------------------
+
 
 use 5.010;
 use strict;
 use warnings;
 
-# ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '1.02';
 
-#-- load the modules -----------------------------------------------------------
+our $VERSION = '1.03';
+
+
 
 use Carp;
 use Params::Util qw(
@@ -64,7 +64,7 @@ use Kafka::Message;
 
 if ( !$BITS64 ) { eval 'use Kafka::Int64; 1;' or die "Cannot load Kafka::Int64 : $@"; } ## no critic
 
-#-- declarations ---------------------------------------------------------------
+
 
 =head1 SYNOPSIS
 
@@ -701,7 +701,7 @@ sub _error {
     return;
 }
 
-#-- Closes and cleans up -------------------------------------------------------
+
 
 1;
 
@@ -800,7 +800,7 @@ L<https://github.com/TrackingSoft/Kafka>
 
 =head1 AUTHOR
 
-Sergey Gladkov, E<lt>sgladkov@trackingsoft.comE<gt>
+Sergey Gladkov
 
 Please use GitHub project link above to report problems or contact authors.
 
