@@ -6,19 +6,19 @@ Kafka::Internals - Constants and functions used internally.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Internals> version 1.02 .
+This documentation refers to C<Kafka::Internals> version 1.03 .
 
 =cut
 
-#-- Pragmas --------------------------------------------------------------------
+
 
 use 5.010;
 use strict;
 use warnings;
 
-# ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '1.02';
+
+our $VERSION = '1.03';
 
 use Exporter qw(
     import
@@ -43,7 +43,7 @@ our @EXPORT_OK = qw(
     format_reference
 );
 
-#-- load the modules -----------------------------------------------------------
+
 
 use overload;
 use Carp;
@@ -59,7 +59,7 @@ use Kafka qw(
     $ERROR_MISMATCH_ARGUMENT
 );
 
-#-- declarations ---------------------------------------------------------------
+
 
 =head1 SYNOPSIS
 
@@ -360,7 +360,7 @@ L<https://github.com/TrackingSoft/Kafka>
 
 =head1 AUTHOR
 
-Sergey Gladkov, E<lt>sgladkov@trackingsoft.comE<gt>
+Sergey Gladkov
 
 Please use GitHub project link above to report problems or contact authors.
 
