@@ -6,23 +6,23 @@ Kafka::Message - Interface to the Kafka message properties.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::Message> version 1.02 .
+This documentation refers to C<Kafka::Message> version 1.03 .
 
 =cut
 
-#-- Pragmas --------------------------------------------------------------------
+
 
 use 5.010;
 use strict;
 use warnings;
 
-# ENVIRONMENT ------------------------------------------------------------------
 
-our $VERSION = '1.02';
 
-#-- load the modules -----------------------------------------------------------
+our $VERSION = '1.03';
+
+
+
 
-#-- declarations ---------------------------------------------------------------
 
 our @_standard_fields = qw(
     Attributes
@@ -68,7 +68,7 @@ sub new {
 
 #-- private methods ------------------------------------------------------------
 
-#-- Closes and cleans up -------------------------------------------------------
+
 
 1;
 
@@ -241,7 +241,7 @@ L<https://github.com/TrackingSoft/Kafka>
 
 =head1 AUTHOR
 
-Sergey Gladkov, E<lt>sgladkov@trackingsoft.comE<gt>
+Sergey Gladkov
 
 Please use GitHub project link above to report problems or contact authors.
 
